"""
SI prefixes for use by units
https://www.bipm.org/en/measurement-units/prefixes.html
"""

YOTTA = 1e24
ZETTA = 1e21
EXA = 1e18
PETA = 1e15
TETRA = 1e12
GIGA = 1e9
MEGA = 1e6
KILO = 1e3
HECTO = 1e2
DECA = 1e1
DECI = 1e-1
CENTI = 1e-2
MILLI = 1e-3
MICRO = 1e-6
NANO = 1e-9
PICO = 1e-12
FEMTO = 1e-15
ATTO = 1e-18
ZEPTO = 1e-21
YOCTO = 1e-24
UNITY = 1   # for reference value
