"""
Data constants

Base unit: Byte
"""

# In bytes
BIT = 0.125     # 1/8
NIBBLE = 0.5    # 4/8

# IEC units
KI = 2**10  # kibi
MI = 2**20  # mebi
GI = 2**30  # gibi
TI = 2**40  # tebi
PI = 2**50  # pebi
EI = 2**60  # exbi
ZI = 2**70  # zebi
YI = 2**80  # yobi
